From c1c0857f7a816b5b3f10fd3554b8bb9b24d1e193 Mon Sep 17 00:00:00 2001
From: neodarz <neodarz@neodarz.net>
Date: Wed, 4 Sep 2019 20:29:22 +0200
Subject: Add some conf

---
 alacritty/.config/alacritty/alacritty.yml |   4 +-
 gnupg/.gnupg/gpg.conf                     |  79 +++++++++++++++++
 i3/.config/i3/config                      |  64 +++++++-------
 install.sh                                | 138 ++++++++++++++++--------------
 nvim/.config/nvim/init.vim                |   2 +-
 xinitrc/.xinitrc                          |   1 +
 zsh/.zsh/aliases.zsh                      |   1 +
 zsh/.zsh/environment.zsh                  |   2 +-
 zsh/.zsh/prompt.zsh                       |   1 +
 9 files changed, 191 insertions(+), 101 deletions(-)

diff --git a/alacritty/.config/alacritty/alacritty.yml b/alacritty/.config/alacritty/alacritty.yml
index d1174be..2b1f4ff 100644
--- a/alacritty/.config/alacritty/alacritty.yml
+++ b/alacritty/.config/alacritty/alacritty.yml
@@ -103,7 +103,7 @@ font:
     #style: Italic
 
   # Point size
-  size: 7.0
+  size: 8.0
 
   # Offset is the extra space around each character. `offset.y` can be thought of
   # as modifying the line spacing, and `offset.x` as modifying the letter spacing.
@@ -125,7 +125,7 @@ font:
   #scale_with_dpi: true
 
 # Display the time it takes to redraw each frame.
-render_timer: false
+debug.render_timer: false
 
 # If `true`, bold text is drawn using the bright color variants.
 draw_bold_text_with_bright_colors: true
diff --git a/gnupg/.gnupg/gpg.conf b/gnupg/.gnupg/gpg.conf
index d8017a9..952c613 100644
--- a/gnupg/.gnupg/gpg.conf
+++ b/gnupg/.gnupg/gpg.conf
@@ -1 +1,80 @@
+# based on https://github.com/ioerror/duraconf
+
+#-----------------------------
+# behavior
+#-----------------------------
+
+# Disable inclusion of the version string in ASCII armored output
+no-emit-version
+
+# Disable comment string in clear text signatures and ASCII armored messages
+no-comments
+
+# Display long key IDs
+keyid-format 0xlong
+
+# List all keys (or the specified ones) along with their fingerprints
+with-fingerprint
+
+# Display the calculed validity of user IDs during key linstings
+list-options show-uid-validity
+verify-options show-uid-validity
+
+# Try to use the GnuPG-Agent. With this option, GnuPG first tries to connect
+# the agent before it asks a passphrase.
+use-agent
+
+#-----------------------------
+# keyserver
+#-----------------------------
+
+# This is the server that --recv-keys, --send-keys, and --search-keys will
+# communicate with to receive keys from, send keys to, and search for keys on
+#keyserver hkps://keys.openpgp.org
+keyserver hkp://pool.sks-keyservers.net
+
+# Provide a certificate store to override the system default
+# Get this from https://sks-keyservers.net/sks-keyservers.netCA.pem
+#keyserver-options ca-cert-file=/usr/local/etc/ssl/certs/hkps.pool.sks-keyservers.net.pem
+# NOT USED FOR THE MOMENT BECAUSE IT'S A DIFFERENT KEY NETWORK
+
+# Set the proxy to use for HTTP and HKP keyservers - default to the standard
+# local Tor socks proxy
+# It is encoraged to use Tor for improved anonymity. Preferrably use aither
+# a dedicated SOCKSPort for GnuPG and/or enable IsolateDestPort and
+# IsolateDestAddr
+#keyserver-options http-proxy=socks5-hostname://127.0.0.1:9050
+
+# Don't leak DNS, see https://trac.torproject.org/projects/tor/ticket/2846
+#keyserver-options no-try-dns-srv
+# Seems to be ok now (comment 51 of ticket)
+
+# when using --refresh-keys, if the key in question has preferred keyserver
+# url, then disable use of that preferred keyserver to regresh the key from
+keyserver-options no-honor-keyserver-url
+
+# When searching for a key with --search-keys, include keys that are marked on
+# the keyserver as revoked
+keyserver-options include-revoked
+
+#-----------------------------
+# algorithm and ciphers
+#-----------------------------
+
+# list of personal digest preferences. When multiple digest are supported by
+# all recipients, choose the stringest one
+personal-cipher-preferences AES256 AES192 AES CAST5
+
+# list of personal digest preferences. WHen multiple ciphers are supported by
+# all recipients, choose the strongest one
+personal-digest-preferences SHA512 SHA384 SHA224
+
+# message digest algorithm used when signing a key
+cert-digest-algo SHA512
+
+# This preference list is used for new keys and becomes the default tor
+# 'setpref' in the edit menu
+default-preference-list SHA512 SHA384 SHA256 AES256 AES192 AES CAST5 ZLIB BZIP2 ZIP Uncompressed
+
+
 pinentry-mode default
diff --git a/i3/.config/i3/config b/i3/.config/i3/config
index da7373c..3651340 100644
--- a/i3/.config/i3/config
+++ b/i3/.config/i3/config
@@ -192,38 +192,38 @@ bindsym $WinKey+q focus parent
 #bindsym $WinKey+d focus child
 
 # Set ~6 workspace par screen (20)
-workspace 1 output DVI-0
-workspace 2 output DVI-0
-workspace 3 output DVI-0
-workspace 4 output DVI-0
-workspace 5 output DVI-0
-workspace 6 output DVI-0
-workspace 7 output DVI-0
-workspace 8 output DVI-0
-workspace 9 output DVI-0
-workspace 10 output DVI-0
-
-workspace 11 output DVI-1
-workspace 12 output DVI-1
-workspace 13 output DVI-1
-workspace 14 output DVI-1
-workspace 15 output DVI-1
-workspace 16 output DVI-1
-workspace 17 output DVI-1
-workspace 18 output DVI-1
-workspace 19 output DVI-1
-workspace 20 output DVI-1
-
-workspace 21 output HDMI-0
-workspace 22 output HDMI-0
-workspace 23 output HDMI-0
-workspace 24 output HDMI-0
-workspace 25 output HDMI-0
-workspace 26 output HDMI-0
-workspace 27 output HDMI-0
-workspace 28 output HDMI-0
-workspace 29 output HDMI-0
-workspace 30 output HDMI-0
+workspace 1 output DP-1
+workspace 2 output DP-1
+workspace 3 output DP-1
+workspace 4 output DP-1
+workspace 5 output DP-1
+workspace 6 output DP-1
+workspace 7 output DP-1
+workspace 8 output DP-1
+workspace 9 output DP-1
+workspace 10 output DP-1
+
+workspace 11 output DP-3
+workspace 12 output DP-3
+workspace 13 output DP-3
+workspace 14 output DP-3
+workspace 15 output DP-3
+workspace 16 output DP-3
+workspace 17 output DP-3
+workspace 18 output DP-3
+workspace 19 output DP-3
+workspace 20 output DP-3
+
+workspace 21 output DP-5
+workspace 22 output DP-5
+workspace 23 output DP-5
+workspace 24 output DP-5
+workspace 25 output DP-5
+workspace 26 output DP-5
+workspace 27 output DP-5
+workspace 28 output DP-5
+workspace 29 output DP-5
+workspace 30 output DP-5
 
 # move focused window between monitors
 bindsym $WinKey+Control+Shift+greater move workspace to output right
diff --git a/nvim/.config/nvim/init.vim b/nvim/.config/nvim/init.vim
index 9c6f1bd..f45a03c 100644
--- a/nvim/.config/nvim/init.vim
+++ b/nvim/.config/nvim/init.vim
@@ -402,7 +402,7 @@ let g:php_cs_fixer_enable_default_mapping = 1     " Enable the mapping by defaul
 let g:php_cs_fixer_dry_run = 0                    " Call command with dry-run option
 let g:php_cs_fixer_verbose = 0                    " Return the output of command if 1, else an inline information.
 
-let g:grammalecte_cli_py='/usr/bin/grammalecte-cli.py'
+let g:grammalecte_cli_py='/usr/bin/grammalecte-cli'
 
 nmap <F8> :TagbarToggle<CR>
 
diff --git a/xinitrc/.xinitrc b/xinitrc/.xinitrc
index 7d55e3a..718c66d 100755
--- a/xinitrc/.xinitrc
+++ b/xinitrc/.xinitrc
@@ -39,5 +39,6 @@ if [ -d /etc/X11/xinit/xinitrc.d ] ; then
     done
     unset f
 fi
+xhost si:localuser:boinc
 
 exec i3
diff --git a/zsh/.zsh/aliases.zsh b/zsh/.zsh/aliases.zsh
index 589cf93..9c4a220 100755
--- a/zsh/.zsh/aliases.zsh
+++ b/zsh/.zsh/aliases.zsh
@@ -311,3 +311,4 @@ if [[ "$SSH_AGENT_PID" == "" ]]; then
     eval "$(<~/.ssh-agent-thing)"
 fi
 
+alias librefox="firefox -p librefox --no-remote"
diff --git a/zsh/.zsh/environment.zsh b/zsh/.zsh/environment.zsh
index 27e7fdf..f158b11 100755
--- a/zsh/.zsh/environment.zsh
+++ b/zsh/.zsh/environment.zsh
@@ -18,7 +18,7 @@
 #HIST_STAMPS=mm/dd/yyyy
 
 #█▓▒░ paths
-export PATH=$HOME/bin:/usr/local/bin:/home/neodarz/.gem/ruby/2.6.0/bin:/home/neodarz/.local/bin::/home/neodarz/go/bin:$HOME/.rbenv/bin:$PATH
+export PATH=$HOME/bin:/usr/local/bin:/home/neodarz/.gem/ruby/2.6.0/bin:/home/neodarz/.local/bin::/home/neodarz/go/bin:$HOME/.rbenv/bin:/opt/cuda/bin:$PATH
 #export MANPATH=/usr/local/man:$MANPATH
 
 #█▓▒░ preferred editor for local and remote sessions
diff --git a/zsh/.zsh/prompt.zsh b/zsh/.zsh/prompt.zsh
index 3e323dd..9c5fce6 100644
--- a/zsh/.zsh/prompt.zsh
+++ b/zsh/.zsh/prompt.zsh
@@ -115,3 +115,4 @@ function host() {
 
 PROMPT='%F{white}┌─[${USER_LEVEL}$USER$reset_color%F{white}@$(host)]─$(git_prompt_string)$(error)[%~]
 └─ - %f'
+setfont lat0-08
diff --git a/install.sh b/install.sh
index 0af6928..89388de 100755
--- a/install.sh
+++ b/install.sh
@@ -1,41 +1,39 @@
 #!/bin/sh
 
 # -- useful packages
 #pacman -S wget
 #pacman -S python
 #pacman -S python2
 #pacman -S python-virtualenv
 #pacman -S python2-virtualenv
 #pacman -S python-virtualenvwrapper
 #pacman -S python-pip
 #pacman -S python-colour
 #pacman -S python-netifaces
 #pacman -S python-dbus
 #pacman -S firefox
 #pacman -S stow
 #pacman -S htop
 #pacman -S arandr
 #pacman -S firefox
 #pacman -S newsboat
 #pacman -S mosh
 #pacman -S openvpn
 #pacman -S exa
 #pacman -S colordiff
 #pacman -S eog
 #pacman -S borg
 #pacman -S nmap
 #pacman -S evince
 #pacman -S ripgrep
 #pacman -S thefuck
 #pacman -S autojump
 #pacman -S fzf
 #pacman -S speedtest-cli
 #pacman -S tig
 #pacman -S redshift
 #pacman -S task
 #pacman -S pavucontrol
 #pacman -S friendly-find
 #pacman -S nerd-fonts-complete
 
 # pikaur installation
 #git clone https://aur.archlinux.org/pikaur.git
@@ -44,13 +42,15 @@
 
 #pikaur -S waterfox-bin
 #pikaur -S grv
+#pikaur -S friendly-find
+#pikaur -S nerd-fonts-complete
 
 #stow scripts
 
 # -- extra package
 
 # Install support windaube file system
-#pacman -S dosfstools
+#sudo pacman -S dosfstools
 #pikaur -S ntfsprogs
 
 #pikaur -S thinkfan
@@ -59,7 +59,7 @@
 
 # -- package with confs
 
-#pacman -S zsh
+#sudo pacman -S zsh
 #stow zsh
 
 ## After zsh installed, install this three plugins :
@@ -71,8 +71,8 @@
 
 #chsh -s $(which zsh)
 
-# pikaur -S twmn-git
-#stow twmnd
+#pikaur -S twmn-git
+#stow twmn
 #systemctl --user enable twmnd.service
 #sed -i s/absolute_position=1920x25/absolute_position=3840x25/g ~/.config/twmn/twmn.conf
 #systemctl --user start twmnd.service
@@ -81,16 +81,16 @@
 
 #stow nvim
 
-#it clone https://github.com/vundlevim/vundle.vim.git ~/.config/nvim/bundle/Vundle.vim
+#git clone https://github.com/vundlevim/vundle.vim.git ~/.config/nvim/bundle/Vundle.vim
 
 #nvim +PluginInstall +qall
 
 #pacman -S xinit
 #pacman -S xorg
 #pacman -S i3-wm
 #pikaur -S i3lock-fancy-multimonitor-git
 #pacman -S rofi
 #pacman -S python-i3-py
 
 #stow i3
 #stow xinitrc
@@ -100,7 +100,7 @@
 
 #stow Xresources
 
-#pacman -S alacritty
+#sudo pacman -S alacritty
 #stow alacritty
 
 #install php version management
@@ -109,7 +109,7 @@
 
 # -- DHCP and DNS "manual" mode
 # Local DNS
-#pacman -S dnsmasq
+#sudo pacman -S dnsmasq
 #sudo stow -t / dnsmasq
 
 #sudo systemctl enable dnsmasq.service
@@ -124,10 +124,10 @@
 #sudo systemctl enable dhcpcd.service
 
 # -- DHCP and DNS "auto" mode
-#pacman -S networkmanager
+#sudo pacman -S networkmanager
 #sudo stow -t / networkmanager
 
-#pacman -S syncthing
+#sudo pacman -S syncthing
 #systemctl --user enable syncthing.service
 #systemctl --user start syncthing.service
 #Config is here : http://127.0.0.1:8384/
@@ -135,39 +135,47 @@
 # Install project manager prm
 #git clone https://github.com/eivind88/prm.git ~/.prm-bin
 
-#pacman -S pulseaudio
+#sudo pacman -S pulseaudio
 #systemctl --user start pulseaudio.service
 #systemctl --user enable pulseaudio.service
 
 #pikaur -S cheat-git
 #stow cheat
 
-#pacman -S pass
+#sudo pacman -S pass
 
 # Export and Import gpg key, this is needed for the next steps
+# And don't forget to clone password-store git repo
 
-#pacman -S offlineimap
+#pikaur -S rofi-pass
+
+#sudo pacman -S offlineimap
 #stow offlineimap
 
+# sync mail
+offlineimap
+
 # Install neomutt
 
 #pacman -S neomutt
 #pacman -S notmuch
 #pacman -S w3m
 #stow notmuch
 #stow mutt
 
 #offlineimap
-#notmuch new
+notmuch new
 
-#pacman -S msmtp
-#stow msmtp
+sudo pacman -S msmtp
+stow msmtp
 
-#pikaur -S rofi-pass
+sudo pacman -S khal
+sudo pacman -S vdirsyncer
+stow khal
+stow vdirsyncer
+vdirsyncer discover
+vdirsyncer sync
+
+# --- xdg config
 
-#pacman -S khal
-#pacman -S vdirsyncer
-#stow khal
-#stow vdirsyncer
-#vdirsyncer discover
-#vdirsyncer sync
+#xdg-settings set default-web-browser firefox.desktop
@@ -1,41 +1,39 @@
 
 # -- useful packages
-#pacman -S wget
-#pacman -S python
-#pacman -S python2
-#pacman -S python-virtualenv
-#pacman -S python2-virtualenv
-#pacman -S python-virtualenvwrapper
-#pacman -S python-pip
-#pacman -S python-colour
-#pacman -S python-netifaces
-#pacman -S python-dbus
-#pacman -S firefox
-#pacman -S stow
-#pacman -S htop
-#pacman -S arandr
-#pacman -S firefox
-#pacman -S newsboat
-#pacman -S mosh
-#pacman -S openvpn
-#pacman -S exa
-#pacman -S colordiff
-#pacman -S eog
-#pacman -S borg
-#pacman -S nmap
-#pacman -S evince
-#pacman -S ripgrep
-#pacman -S thefuck
-#pacman -S autojump
-#pacman -S fzf
-#pacman -S speedtest-cli
-#pacman -S tig
-#pacman -S redshift
-#pacman -S task
-#pacman -S pavucontrol
-#pacman -S friendly-find
-#pacman -S nerd-fonts-complete
+#sudo pacman -S wget
+#sudo pacman -S python
+#sudo pacman -S python2
+#sudo pacman -S python-virtualenv
+#sudo pacman -S python2-virtualenv
+#sudo pacman -S python-virtualenvwrapper
+#sudo pacman -S python-pip
+#sudo pacman -S python-colour
+#sudo pacman -S python-netifaces
+#sudo pacman -S python-dbus
+#sudo pacman -S firefox
+#sudo pacman -S stow
+#sudo pacman -S htop
+#sudo pacman -S arandr
+#sudo pacman -S firefox
+#sudo pacman -S newsboat
+#sudo pacman -S mosh
+#sudo pacman -S openvpn
+#sudo pacman -S exa
+#sudo pacman -S colordiff
+#sudo pacman -S eog
+#sudo pacman -S borg
+#sudo pacman -S nmap
+#sudo pacman -S evince
+#sudo pacman -S ripgrep
+#sudo pacman -S thefuck
+#sudo pacman -S autojump
+#sudo pacman -S fzf
+#sudo pacman -S speedtest-cli
+#sudo pacman -S tig
+#sudo pacman -S redshift
+#sudo pacman -S task
+#sudo pacman -S pavucontrol
 
 # pikaur installation
@@ -81,16 +81,16 @@
 #nvim +PluginInstall +qall
 
-#pacman -S xinit
-#pacman -S xorg
-#pacman -S i3-wm
+#sudo pacman -S xinit
+#sudo pacman -S xorg
+#sudo pacman -S i3-wm
 #pikaur -S i3lock-fancy-multimonitor-git
@@ -81,16 +81,16 @@
 #pikaur -S i3lock-fancy-multimonitor-git
-#pacman -S rofi
-#pacman -S python-i3-py
+#sudo pacman -S rofi
+#sudo pacman -S python-i3-py
 
 #stow i3
@@ -135,39 +135,47 @@
 # Install neomutt
 
-#pacman -S neomutt
-#pacman -S notmuch
-#pacman -S w3m
+#sudo pacman -S neomutt
+#sudo pacman -S notmuch
+#sudo pacman -S w3m
 #stow notmuch
 #stow mutt
-- 
cgit v1.2.1